@@ -96,6 +96,9 @@ def multifunc(function,allvars,procaxis,vardims):
                 for idim2 in range(len(vardims[ivar])): #reversed(range(dimcount)):
                     if vardims[ivar][idim2] != None:
                         vardims[ivar][idim2] = vardims[ivar][idim2] + 1
+
+
+
                     
     # put dimensions of all variables arrays in the same order 
     # as the standard order (which is implicitely given by vardims)
@@ -105,7 +108,37 @@ def multifunc(function,allvars,procaxis,vardims):
     for ivar,evar in enumerate(allvars):
         allvars[ivar] = transpose(evar,vardims[ivar])
     for ivar,evar in enumerate(allvars):
-        print evar.shape, vardims[ivar]
+        print 'shape before transposition:',evar.shape, vardims[ivar]
+        print 'procaxis:', procaxis
+
+
+    # if a certain dimension has
+    for idim in range(len(procaxis)):
+        # get maximum dimension
+        maxdim = 0
+        for ivar,evar in enumerate(allvars):
+            maxdim = max(shape(evar)[idim],maxdim)
+        for ivar,evar in enumerate(allvars):
+            if ((shape(evar)[idim] == 1) & (maxdim > 1)):
+                print maxdim,idim
+                allvars[ivar] = repeat(allvars[ivar],maxdim,idim)
+                # tmpdim = range(len(procaxis))
+                # tmpdim[idim] = 0
+                # print 'tmpdim 1', tmpdim
+                # for idim2 in range(idim):
+                #     tmpdim[idim2] = tmpdim[idim2] + 1
+                # print 'tmpdim', tmpdim
+                # allvars[ivar] = transpose(allvars[ivar],tmpdim)
+                # allvars[ivar] = repeat(allvars[ivar][:],maxdim,0)
+                # inv = range(len(tmpdim))
+                # for idim2, edim2 in enumerate(tmpdim):
+                #     inv[edim2] = idim2
+                # allvars[ivar] = transpose(allvars[ivar],inv)
+
+    for ivar,evar in enumerate(allvars):
+        print 'shape after expansion:',evar.shape, vardims[ivar]
+        print 'procaxis:', procaxis
+
     
     # now transpose all matrices in a similar way in such a way that the dimensions 
     # to be processed are at the end
@@ -122,7 +155,7 @@ def multifunc(function,allvars,procaxis,vardims):
     # ...
 
     for ivar,evar in enumerate(allvars):
-        print evar.shape, vardims[ivar]
+        print 'shape after transposition:',evar.shape
 
     dataouttrns,outcoordstrnstmp = procdf(function,allvars,trnsprocaxis)
 
